/****************************************************************************** 
 ******************************************************************************
 Section: Included Files
 ******************************************************************************
 *****************************************************************************/
#include <p33EV256GM106.h>
#include "types.h"
#include "motorvariables.h"
/* The system is configured for 20Mhz */
_FOSCSEL(FNOSC_PRIPLL)
_FOSC(FCKSM_CSECMD & POSCMD_XT & OSCIOFNC_OFF & IOL1WAY_OFF)
_FWDT(FWDTEN_OFF)
_FICD(ICS_PGD2)
 #pragma config PWMLOCK = OFF            // PWM Lock Enable Bit (PWM registers may be written without key sequence)
 #pragma config BOREN0 = OFF             // Brown Out Reset Detection Bit (BOR is Disabled)        
/*****************************************************************************
 *****************************************************************************
 Section: MACRO DEFINITION'S
 *****************************************************************************
 *****************************************************************************/
#define NULL             (void *)0u
#define TORQUE_COMMAND   (0x01u)
#define SPEED_COMMAND    (0x02u)
#define STOP_COMMAND     (0x03u)
#define TORQUE_MSGID     (0x103u)
#define SPEED_MSGID      (0x104u)
#define STOP_MSGID       (0x105u)
/****************************************************************************
  Section: File Scope Variables, Functions, Initializations
 *****************************************************************************/
/* Axis definition */
current_T g_current_s;
voltage_T g_voltage_s;
motor_ref_parametres_T g_motor_ref_parametres_s = {-1.0,-1.0,-1.0};
motor_measured_parametres_T g_motor_measured_parameters_s;

extern CANRXID g_canRxMessage;
extern uchar8_t g_datarxed_u8;
extern double32_t g_encoderpulses_u16;

/****************************************************************************
  Section: Function Declarations, extern declarations
 *****************************************************************************/
extern void PwmInitialization(void);
extern void AdcInitialization(void);
extern void InputCaptureInitialization(void);
extern void Init_Timer1(void);
extern void AdcInit(void);

int main(void)
{
   uchar8_t l_command_u8=0;
   struct reference_parameters_tag *l_ptr_s = NULL;
   l_ptr_s = &g_motor_ref_parametres_s;
   
   PLLFBD=18;              // M=48
   CLKDIVbits.PLLPOST=0;   // N2=2
   CLKDIVbits.PLLPRE=0;    // N1=2 
   AdcInit();
   TogglePortInit();
   Init_Timer1();
   Init_Timer3();
   PwmInitialization();
   InputCaptureInitialization();
   while(TRUE)
   {
//    TogglePort();
   }
  return 0;
}

 void TogglePortInit(void)
 {
    _TRISD6 = 0;
 }
 
 void TogglePort(void)
 {
     static uchar8_t l_debug_u8=0;
     _RD6 = l_debug_u8;
     l_debug_u8 = ~l_debug_u8;
 }
 
void HighPort(void)
 {
   _RD6 = 1;
 }
 
 void LowPort(void)
 {
    _RD6 = 0;
 }